@@ -33,32 +33,37 @@
 <context>
     <name>DownloadThread</name>
     <message>
-        <location filename="../downloadthread.cpp" line="114"/>
+        <location filename="../downloadthread.cpp" line="118"/>
+        <source>unmounting drive</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../downloadthread.cpp" line="138"/>
         <source>opening drive</source>
         <translation>Gerät wird geöffnet</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="147"/>
+        <location filename="../downloadthread.cpp" line="166"/>
         <source>Error running diskpart: %1</source>
         <translation>Fehler beim Ausführen von Diskpart: %1</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="168"/>
+        <location filename="../downloadthread.cpp" line="187"/>
         <source>Error removing existing partitions</source>
         <translation>Fehler beim Entfernen von existierenden Partitionen</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="194"/>
+        <location filename="../downloadthread.cpp" line="213"/>
         <source>Authentication cancelled</source>
         <translation>Authentifizierung abgebrochen</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="197"/>
+        <location filename="../downloadthread.cpp" line="216"/>
         <source>Error running authopen to gain access to disk device &apos;%1&apos;</source>
         <translation>Fehler beim Ausführen von authopen, um Zugriff auf Geräte zu erhalten &apos;%1&apos;</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="198"/>
+        <location filename="../downloadthread.cpp" line="217"/>
         <source>Please verify if &apos;Raspberry Pi Imager&apos; is allowed access to &apos;removable volumes&apos; in privacy settings (under &apos;files and folders&apos; or alternatively give it &apos;full disk access&apos;).</source>
         <translatorcomment>I don&apos;t use Mac OS, I would need help here. Unfinished translation:
 
@@ -66,97 +71,88 @@ Bitte stellen Sie sicher, dass &apos;Raspberry Pi Imager&apos; Zugriff auf &apos
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="220"/>
+        <location filename="../downloadthread.cpp" line="239"/>
         <source>Cannot open storage device &apos;%1&apos;.</source>
         <translation>Speichergerät &apos;%1&apos; kann nicht geöffnet werden.</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="262"/>
+        <location filename="../downloadthread.cpp" line="281"/>
         <source>discarding existing data on drive</source>
         <translation>Vorhandene Daten auf dem Medium werden gelöscht</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="282"/>
+        <location filename="../downloadthread.cpp" line="301"/>
         <source>zeroing out first and last MB of drive</source>
         <translation>Erstes und letztes Megabyte des Mediums werden überschrieben</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="288"/>
+        <location filename="../downloadthread.cpp" line="307"/>
         <source>Write error while zero&apos;ing out MBR</source>
         <translation>Schreibfehler während des Löschens des MBR</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="300"/>
+        <location filename="../downloadthread.cpp" line="319"/>
         <source>Write error while trying to zero out last part of card.&lt;br&gt;Card could be advertising wrong capacity (possible counterfeit).</source>
         <translation>Fehler beim Löschen des letzten Teiles der Speicherkarte.&lt;br&gt;Die Speicherkarte könnte mit einer falschen Größe beworben sein (möglicherweise Betrug).</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="389"/>
+        <location filename="../downloadthread.cpp" line="408"/>
         <source>starting download</source>
         <translation>Download wird gestartet</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="779"/>
+        <location filename="../downloadthread.cpp" line="813"/>
         <source>Error reading from storage.&lt;br&gt;SD card may be broken.</source>
         <translation>Fehler beim Lesen vom Speicher.&lt;br&gt;Die SD-Karte könnte defekt sein.</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="855"/>
         <source>Waiting for FAT partition to be mounted</source>
-        <translation>Warten auf das Einbinden der FAT-Partition</translation>
+        <translation type="vanished">Warten auf das Einbinden der FAT-Partition</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="941"/>
         <source>Error mounting FAT32 partition</source>
-        <translation>Fehler beim Einbinden der FAT32-Partition</translation>
+        <translation type="vanished">Fehler beim Einbinden der FAT32-Partition</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="963"/>
         <source>Operating system did not mount FAT32 partition</source>
-        <translation>Das Betriebssystem band die FAT32-Partition nicht ein</translation>
+        <translation type="vanished">Das Betriebssystem hat die FAT32-Partition nicht eingebunden.</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="996"/>
         <source>Unable to customize. File &apos;%1&apos; does not exist.</source>
-        <translation type="unfinished"></translation>
+        <translation type="vanished">Modifizieren fehlgeschlagen. Die Datei &apos;%1&apos; existiert nicht.</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="1000"/>
+        <location filename="../downloadthread.cpp" line="885"/>
         <source>Customizing image</source>
         <translation>Image modifizieren</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="1085"/>
         <source>Error creating firstrun.sh on FAT partition</source>
-        <translation>Fehler beim Erstellen von firstrun.sh auf der FAT-Partition</translation>
+        <translation type="vanished">Fehler beim Erstellen von firstrun.sh auf der FAT-Partition</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="1037"/>
         <source>Error writing to config.txt on FAT partition</source>
-        <translation>Fehler beim Schreiben in config.txt auf der FAT-Partition</translation>
+        <translation type="vanished">Fehler beim Schreiben in config.txt auf der FAT-Partition</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="1102"/>
         <source>Error creating user-data cloudinit file on FAT partition</source>
-        <translation type="unfinished"></translation>
+        <translation type="vanished">Fehler beim Erstellen der user-data cloudinit Datei auf der FAT-Partition</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="1116"/>
         <source>Error creating network-config cloudinit file on FAT partition</source>
-        <translation type="unfinished"></translation>
+        <translation type="vanished">Fehler beim Erstellen der network-config cloudinit Datei auf der FAT-Partition</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="1139"/>
         <source>Error writing to cmdline.txt on FAT partition</source>
-        <translation>Fehler beim Schreiben in cmdline.txt auf der FAT-Partition</translation>
+        <translation type="vanished">Fehler beim Schreiben in cmdline.txt auf der FAT-Partition</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="432"/>
+        <location filename="../downloadthread.cpp" line="451"/>
         <source>Access denied error while writing file to disk.</source>
         <translation>Zugriff verweigert-Fehler beim Schreiben auf den Datenträger.</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="437"/>
+        <location filename="../downloadthread.cpp" line="456"/>
         <source>Controlled Folder Access seems to be enabled. Please add both rpi-imager.exe and fat32format.exe to the list of allowed apps and try again.</source>
         <translatorcomment>I don&apos;t use Windows either. What is &quot;Controlled Folder Access&quot; in the German version?
 
@@ -164,37 +160,39 @@ Controlled Folder Access scheint aktiviert zu sein. Bitte fügen Sie sowohl rpi-
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="444"/>
+        <location filename="../downloadthread.cpp" line="463"/>
         <source>Error writing file to disk</source>
         <translation>Fehler beim Schreiben der Datei auf den Speicher</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="463"/>
+        <location filename="../downloadthread.cpp" line="482"/>
         <source>Error downloading: %1</source>
         <translation>Fehler beim Herunterladen: %1</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="674"/>
+        <location filename="../downloadthread.cpp" line="693"/>
         <source>Download corrupt. Hash does not match</source>
         <translation>Download beschädigt. Prüfsumme stimmt nicht überein</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="686"/>
+        <location filename="../downloadthread.cpp" line="705"/>
+        <location filename="../downloadthread.cpp" line="757"/>
         <source>Error writing to storage (while flushing)</source>
         <translation>Fehler beim Schreiben auf den Speicher (während flushing)</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="693"/>
+        <location filename="../downloadthread.cpp" line="712"/>
+        <location filename="../downloadthread.cpp" line="764"/>
         <source>Error writing to storage (while fsync)</source>
         <translation>Fehler beim Schreiben auf den Speicher (während fsync)</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="719"/>
+        <location filename="../downloadthread.cpp" line="747"/>
         <source>Error writing first block (partition table)</source>
         <translation>Fehler beim Schreiben auf des ersten Blocks (Partitionstabelle)</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="798"/>
+        <location filename="../downloadthread.cpp" line="832"/>
         <source>Verifying write failed. Contents of SD card is different from what was written to it.</source>
         <translation>Verifizierung fehlgeschlagen. Der Inhalt der SD-Karte weicht von dem Inhalt ab, der geschrieben werden sollte.</translation>
     </message>
@@ -241,7 +239,7 @@ Controlled Folder Access scheint aktiviert zu sein. Bitte fügen Sie sowohl rpi-
     <message>
         <location filename="../driveformatthread.cpp" line="199"/>
         <source>Partitioning did not create expected FAT partition %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Partitionierung hat nicht die erwartete FAT-partition %1 erstellt</translation>
     </message>
     <message>
         <location filename="../driveformatthread.cpp" line="208"/>
@@ -262,29 +260,29 @@ Controlled Folder Access scheint aktiviert zu sein. Bitte fügen Sie sowohl rpi-
 <context>
     <name>ImageWriter</name>
     <message>
-        <location filename="../imagewriter.cpp" line="257"/>
+        <location filename="../imagewriter.cpp" line="248"/>
         <source>Storage capacity is not large enough.&lt;br&gt;Needs to be at least %1 GB.</source>
         <translation>Die Speicherkapazität ist nicht groß genug.&lt;br&gt;Sie muss mindestens %1 GB betragen.</translation>
     </message>
     <message>
-        <location filename="../imagewriter.cpp" line="263"/>
+        <location filename="../imagewriter.cpp" line="254"/>
         <source>Input file is not a valid disk image.&lt;br&gt;File size %1 bytes is not a multiple of 512 bytes.</source>
         <translation>Die Eingabedatei ist kein gültiges Disk-Image.&lt;br&gt;Die Dateigröße%1 Bytes ist kein Vielfaches von 512 Bytes.</translation>
     </message>
     <message>
-        <location filename="../imagewriter.cpp" line="445"/>
+        <location filename="../imagewriter.cpp" line="442"/>
         <source>Downloading and writing image</source>
         <translation>Image herunterladen und schreiben</translation>
     </message>
     <message>
-        <location filename="../imagewriter.cpp" line="578"/>
+        <location filename="../imagewriter.cpp" line="575"/>
         <source>Select image</source>
         <translation>Image wählen</translation>
     </message>
     <message>
-        <location filename="../imagewriter.cpp" line="979"/>
+        <location filename="../imagewriter.cpp" line="864"/>
         <source>Would you like to prefill the wifi password from the system keychain?</source>
-        <translation type="unfinished"></translation>
+        <translation>Möchten Sie das Wifi-Passwort aus dem System-Schlüsselbund vorab ausfüllen?</translation>
     </message>
 </context>
 <context>
@@ -320,28 +318,28 @@ Controlled Folder Access scheint aktiviert zu sein. Bitte fügen Sie sowohl rpi-
     <message>
         <location filename="../MsgPopup.qml" line="130"/>
         <source>QUIT</source>
-        <translation type="unfinished"></translation>
+        <translation>BEENDEN</translation>
     </message>
 </context>
 <context>
     <name>OptionsPopup</name>
     <message>
-        <location filename="../OptionsPopup.qml" line="79"/>
+        <location filename="../OptionsPopup.qml" line="80"/>
         <source>Advanced options</source>
         <translation>Erweiterte Optionen</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="96"/>
+        <location filename="../OptionsPopup.qml" line="97"/>
         <source>Image customization options</source>
         <translation>OS-Modifizierungen</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="104"/>
+        <location filename="../OptionsPopup.qml" line="105"/>
         <source>for this session only</source>
         <translation>Nur für diese Sitzung</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="105"/>
+        <location filename="../OptionsPopup.qml" line="106"/>
         <source>to always use</source>
         <translation>Immer verwenden</translation>
     </message>
@@ -350,22 +348,22 @@ Controlled Folder Access scheint aktiviert zu sein. Bitte fügen Sie sowohl rpi-
         <translation type="vanished">Overscan deaktivieren</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="119"/>
+        <location filename="../OptionsPopup.qml" line="120"/>
         <source>Set hostname:</source>
         <translation>Hostname:</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="138"/>
+        <location filename="../OptionsPopup.qml" line="140"/>
         <source>Enable SSH</source>
         <translation>SSH aktivieren</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="160"/>
+        <location filename="../OptionsPopup.qml" line="162"/>
         <source>Use password authentication</source>
         <translation>Password zur Authentifizierung verwenden</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="170"/>
+        <location filename="../OptionsPopup.qml" line="172"/>
         <source>Allow public-key authentication only</source>
         <translation>Authentifizierung via Public-Key</translation>
     </message>
@@ -374,63 +372,63 @@ Controlled Folder Access scheint aktiviert zu sein. Bitte fügen Sie sowohl rpi-
         <translation type="vanished">Passwort für &apos;%1&apos;:</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="188"/>
+        <location filename="../OptionsPopup.qml" line="190"/>
         <source>Set authorized_keys for &apos;%1&apos;:</source>
         <translation>authorized_keys für &apos;%1&apos;:</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="261"/>
+        <location filename="../OptionsPopup.qml" line="264"/>
         <source>Configure wireless LAN</source>
         <translation>Wifi einrichten</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="280"/>
+        <location filename="../OptionsPopup.qml" line="283"/>
         <source>SSID:</source>
         <translation>SSID:</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="234"/>
-        <location filename="../OptionsPopup.qml" line="300"/>
+        <location filename="../OptionsPopup.qml" line="237"/>
+        <location filename="../OptionsPopup.qml" line="303"/>
         <source>Password:</source>
         <translation>Passwort:</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="200"/>
+        <location filename="../OptionsPopup.qml" line="203"/>
         <source>Set username and password</source>
         <translation>Benutzername und Passwort setzen:</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="219"/>
+        <location filename="../OptionsPopup.qml" line="222"/>
         <source>Username:</source>
         <translation>Benutzername:</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="295"/>
+        <location filename="../OptionsPopup.qml" line="298"/>
         <source>Hidden SSID</source>
-        <translation type="unfinished"></translation>
+        <translation>Verborgene SSID</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="316"/>
+        <location filename="../OptionsPopup.qml" line="319"/>
         <source>Show password</source>
         <translation>Passwort anzeigen</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="321"/>
+        <location filename="../OptionsPopup.qml" line="324"/>
         <source>Wireless LAN country:</source>
         <translation>Wifi-Land:</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="332"/>
+        <location filename="../OptionsPopup.qml" line="335"/>
         <source>Set locale settings</source>
         <translation>Spracheinstellungen festlegen</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="342"/>
+        <location filename="../OptionsPopup.qml" line="345"/>
         <source>Time zone:</source>
         <translation>Zeitzone:</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="352"/>
+        <location filename="../OptionsPopup.qml" line="355"/>
         <source>Keyboard layout:</source>
         <translation>Tastaturlayout:</translation>
     </message>
@@ -439,27 +437,27 @@ Controlled Folder Access scheint aktiviert zu sein. Bitte fügen Sie sowohl rpi-
         <translation type="vanished">Einrichtungsassistent überspringen</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="365"/>
+        <location filename="../OptionsPopup.qml" line="368"/>
         <source>Persistent settings</source>
         <translation>Dauerhafte Einstellungen</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="373"/>
+        <location filename="../OptionsPopup.qml" line="376"/>
         <source>Play sound when finished</source>
         <translation>Tonsignal nach Beenden abspielen</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="377"/>
+        <location filename="../OptionsPopup.qml" line="380"/>
         <source>Eject media when finished</source>
         <translation>Medien nach Beenden auswerfen</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="381"/>
+        <location filename="../OptionsPopup.qml" line="384"/>
         <source>Enable telemetry</source>
         <translation>Telemetry aktivieren</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="394"/>
+        <location filename="../OptionsPopup.qml" line="397"/>
         <source>SAVE</source>
         <translation>SPEICHERN</translation>
     </message>
@@ -475,27 +473,32 @@ Controlled Folder Access scheint aktiviert zu sein. Bitte fügen Sie sowohl rpi-
 <context>
     <name>UseSavedSettingsPopup</name>
     <message>
-        <location filename="../UseSavedSettingsPopup.qml" line="72"/>
+        <location filename="../UseSavedSettingsPopup.qml" line="73"/>
         <source>Warning: advanced settings set</source>
         <translation>Warnung: Erweiterte Optionen festgelegt</translation>
     </message>
     <message>
-        <location filename="../UseSavedSettingsPopup.qml" line="86"/>
+        <location filename="../UseSavedSettingsPopup.qml" line="87"/>
         <source>Would you like to apply the image customization settings saved earlier?</source>
         <translation>Möchten Sie die vorher festgelegten OS-Modifizierungen anwenden?</translation>
     </message>
     <message>
-        <location filename="../UseSavedSettingsPopup.qml" line="95"/>
+        <location filename="../UseSavedSettingsPopup.qml" line="96"/>
+        <source>NO</source>
+        <translation>NEIN</translation>
+    </message>
+    <message>
+        <location filename="../UseSavedSettingsPopup.qml" line="106"/>
         <source>NO, CLEAR SETTINGS</source>
         <translation>NEIN, EINSTELLUNGEN LÖSCHEN</translation>
     </message>
     <message>
-        <location filename="../UseSavedSettingsPopup.qml" line="105"/>
+        <location filename="../UseSavedSettingsPopup.qml" line="116"/>
         <source>YES</source>
         <translation>JA</translation>
     </message>
     <message>
-        <location filename="../UseSavedSettingsPopup.qml" line="115"/>
+        <location filename="../UseSavedSettingsPopup.qml" line="126"/>
         <source>EDIT SETTINGS</source>
         <translation>EINSTELLUNGEN BEARBEITEN</translation>
     </message>
@@ -531,7 +534,7 @@ Controlled Folder Access scheint aktiviert zu sein. Bitte fügen Sie sowohl rpi-
     </message>
     <message>
         <location filename="../main.qml" line="147"/>
-        <location filename="../main.qml" line="1038"/>
+        <location filename="../main.qml" line="1041"/>
         <source>CHOOSE STORAGE</source>
         <translation>SD-KARTE WÄHLEN</translation>
     </message>
@@ -556,7 +559,7 @@ Controlled Folder Access scheint aktiviert zu sein. Bitte fügen Sie sowohl rpi-
     </message>
     <message>
         <location filename="../main.qml" line="221"/>
-        <location filename="../main.qml" line="965"/>
+        <location filename="../main.qml" line="968"/>
         <source>Cancelling...</source>
         <translation>Abbrechen...</translation>
     </message>
@@ -567,14 +570,14 @@ Controlled Folder Access scheint aktiviert zu sein. Bitte fügen Sie sowohl rpi-
     </message>
     <message>
         <location filename="../main.qml" line="232"/>
-        <location filename="../main.qml" line="988"/>
-        <location filename="../main.qml" line="1057"/>
+        <location filename="../main.qml" line="991"/>
+        <location filename="../main.qml" line="1060"/>
         <source>Finalizing...</source>
         <translation>Finalisieren...</translation>
     </message>
     <message>
         <location filename="../main.qml" line="505"/>
-        <location filename="../main.qml" line="1022"/>
+        <location filename="../main.qml" line="1025"/>
         <source>Erase</source>
         <translation>Löschen</translation>
     </message>
@@ -606,12 +609,12 @@ Controlled Folder Access scheint aktiviert zu sein. Bitte fügen Sie sowohl rpi-
     <message>
         <location filename="../main.qml" line="247"/>
         <source>Select this button to access advanced settings</source>
-        <translation type="unfinished"></translation>
+        <translation>Klicken Sie auf diesen Knopf, um zu den erweiterten Einstellungen zu gelangen.</translation>
     </message>
     <message>
         <location filename="../main.qml" line="261"/>
         <source>Using custom repository: %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Verwende benutzerdefiniertes Repository: %1</translation>
     </message>
     <message>
         <location filename="../main.qml" line="270"/>
@@ -621,12 +624,12 @@ Controlled Folder Access scheint aktiviert zu sein. Bitte fügen Sie sowohl rpi-
     <message>
         <location filename="../main.qml" line="290"/>
         <source>Language: </source>
-        <translation type="unfinished"></translation>
+        <translation>Sprache: </translation>
     </message>
     <message>
         <location filename="../main.qml" line="313"/>
         <source>Keyboard: </source>
-        <translation type="unfinished"></translation>
+        <translation>Tastatur: </translation>
     </message>
     <message>
         <location filename="../main.qml" line="462"/>
@@ -696,7 +699,7 @@ Controlled Folder Access scheint aktiviert zu sein. Bitte fügen Sie sowohl rpi-
         <translation>Eine neuere Version von Imager ist verfügbar. &lt;br&gt;Möchten Sie die Webseite besuchen, um das Update herunterzuladen?</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="968"/>
+        <location filename="../main.qml" line="971"/>
         <source>Writing... %1%</source>
         <translation>Schreiben... %1%</translation>
     </message>
@@ -706,32 +709,32 @@ Controlled Folder Access scheint aktiviert zu sein. Bitte fügen Sie sowohl rpi-
         <translation>Alle vorhandenen Daten auf &apos;%1&apos; werden gelöscht.&lt;br&gt;Möchten Sie wirklich fortfahren?</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="947"/>
+        <location filename="../main.qml" line="950"/>
         <source>Error downloading OS list from Internet</source>
         <translation>Fehler beim Herunterladen der Betriebssystemsliste aus dem Internet</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="991"/>
+        <location filename="../main.qml" line="994"/>
         <source>Verifying... %1%</source>
         <translation>Verifizierung... %1%</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="998"/>
+        <location filename="../main.qml" line="1001"/>
         <source>Preparing to write... (%1)</source>
         <translation>Schreiben wird vorbereitet... (%1)</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="1014"/>
+        <location filename="../main.qml" line="1017"/>
         <source>Error</source>
         <translation>Fehler</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="1021"/>
+        <location filename="../main.qml" line="1024"/>
         <source>Write Successful</source>
         <translation>Schreiben erfolgreich</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="1023"/>
+        <location filename="../main.qml" line="1026"/>
         <source>&lt;b&gt;%1&lt;/b&gt; has been erased&lt;br&gt;&lt;br&gt;You can now remove the SD card from the reader</source>
         <translation>&lt;b&gt;%1&lt;/b&gt; wurde geleert&lt;br&gt;&lt;br&gt;Sie können die SD-Karte nun aus dem Lesegerät entfernen</translation>
     </message>
@@ -740,22 +743,22 @@ Controlled Folder Access scheint aktiviert zu sein. Bitte fügen Sie sowohl rpi-
         <translation type="vanished">&lt;b&gt;%1&lt;/b&gt; wurde auf &lt;b&gt;%2&lt;/b&gt; geschrieben</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="1030"/>
+        <location filename="../main.qml" line="1033"/>
         <source>&lt;b&gt;%1&lt;/b&gt; has been written to &lt;b&gt;%2&lt;/b&gt;&lt;br&gt;&lt;br&gt;You can now remove the SD card from the reader</source>
         <translation>&lt;b&gt;%1&lt;/b&gt; wurde auf &lt;b&gt;%2&lt;/b&gt; geschrieben&lt;br&gt;&lt;br&gt;Sie können die SD-Karte nun aus dem Lesegerät entfernen</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="1098"/>
+        <location filename="../main.qml" line="1101"/>
         <source>Error parsing os_list.json</source>
         <translation>Fehler beim Parsen von os_list.json</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="1271"/>
+        <location filename="../main.qml" line="1274"/>
         <source>Connect an USB stick containing images first.&lt;br&gt;The images must be located in the root folder of the USB stick.</source>
         <translation>Verbinden Sie zuerst einen USB-Stick mit Images.&lt;br&gt;Die Images müssen sich im Wurzelverzeichnes des USB-Sticks befinden.</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="1287"/>
+        <location filename="../main.qml" line="1290"/>
         <source>SD card is write protected.&lt;br&gt;Push the lock switch on the left side of the card upwards, and try again.</source>
         <translation>Die Speicherkarte ist schreibgeschützt.&lt;br&gt;Schieben Sie den Schutzschalter auf der linken Seite nach oben, und versuchen Sie es erneut.</translation>
     </message>
