@@ -33,162 +33,148 @@
 <context>
     <name>DownloadThread</name>
     <message>
-        <location filename="../downloadthread.cpp" line="147"/>
+        <location filename="../downloadthread.cpp" line="166"/>
         <source>Error running diskpart: %1</source>
         <translation>运行 “diskpart” 命令错误 %1</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="168"/>
+        <location filename="../downloadthread.cpp" line="187"/>
         <source>Error removing existing partitions</source>
         <translation>删除现有分区时出错</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="194"/>
+        <location filename="../downloadthread.cpp" line="213"/>
         <source>Authentication cancelled</source>
         <translation>认证已取消</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="197"/>
+        <location filename="../downloadthread.cpp" line="216"/>
         <source>Error running authopen to gain access to disk device &apos;%1&apos;</source>
         <translation>运行authopen以获得对磁盘设备&apos;%1&apos;的访问权限时出错</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="198"/>
+        <location filename="../downloadthread.cpp" line="217"/>
         <source>Please verify if &apos;Raspberry Pi Imager&apos; is allowed access to &apos;removable volumes&apos; in privacy settings (under &apos;files and folders&apos; or alternatively give it &apos;full disk access&apos;).</source>
         <translation>请验证是否在隐私设置中允许“ Raspberry Pi Imager”访问“可移动卷”（在“文件和文件夹”下，或者为它提供“完全磁盘访问”）的权限。</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="220"/>
+        <location filename="../downloadthread.cpp" line="239"/>
         <source>Cannot open storage device &apos;%1&apos;.</source>
         <translation>无法打开存储设备&apos;%1&apos;。</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="262"/>
+        <location filename="../downloadthread.cpp" line="281"/>
         <source>discarding existing data on drive</source>
         <translation>删除现有数据</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="282"/>
+        <location filename="../downloadthread.cpp" line="301"/>
         <source>zeroing out first and last MB of drive</source>
         <translation>清空驱动器未使用的数据</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="288"/>
+        <location filename="../downloadthread.cpp" line="307"/>
         <source>Write error while zero&apos;ing out MBR</source>
         <translation>将MBR清零时写入错误</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="779"/>
+        <location filename="../downloadthread.cpp" line="813"/>
         <source>Error reading from storage.&lt;br&gt;SD card may be broken.</source>
         <translation>从存储读取数据时错误。&lt;br&gt;SD卡可能已损坏。</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="855"/>
         <source>Waiting for FAT partition to be mounted</source>
-        <translation>等待FAT分区挂载</translation>
+        <translation type="vanished">等待FAT分区挂载</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="941"/>
         <source>Error mounting FAT32 partition</source>
-        <translation>挂载FAT32分区错误</translation>
+        <translation type="vanished">挂载FAT32分区错误</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="963"/>
         <source>Operating system did not mount FAT32 partition</source>
-        <translation>操作系统未能挂载FAT32分区</translation>
+        <translation type="vanished">操作系统未能挂载FAT32分区</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="996"/>
-        <source>Unable to customize. File &apos;%1&apos; does not exist.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../downloadthread.cpp" line="1000"/>
+        <location filename="../downloadthread.cpp" line="885"/>
         <source>Customizing image</source>
         <translation>使用自定义镜像</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="1085"/>
         <source>Error creating firstrun.sh on FAT partition</source>
-        <translation>在FAT分区上创建firstrun.sh脚本文件时出错</translation>
+        <translation type="vanished">在FAT分区上创建firstrun.sh脚本文件时出错</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="1037"/>
         <source>Error writing to config.txt on FAT partition</source>
-        <translation>在FAT分区上写入config.txt时出错</translation>
+        <translation type="vanished">在FAT分区上写入config.txt时出错</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="1102"/>
-        <source>Error creating user-data cloudinit file on FAT partition</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../downloadthread.cpp" line="1116"/>
-        <source>Error creating network-config cloudinit file on FAT partition</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../downloadthread.cpp" line="1139"/>
         <source>Error writing to cmdline.txt on FAT partition</source>
-        <translation>在FAT分区上写入cmdline.txt时出错</translation>
+        <translation type="vanished">在FAT分区上写入cmdline.txt时出错</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="432"/>
+        <location filename="../downloadthread.cpp" line="451"/>
         <source>Access denied error while writing file to disk.</source>
         <translation>将文件写入磁盘时访问被拒绝。</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="437"/>
+        <location filename="../downloadthread.cpp" line="456"/>
         <source>Controlled Folder Access seems to be enabled. Please add both rpi-imager.exe and fat32format.exe to the list of allowed apps and try again.</source>
         <translation>受控文件夹访问似乎已启用。 请将rpi-imager.exe和fat32format.exe都添加到允许的应用程序列表中，然后重试。</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="444"/>
+        <location filename="../downloadthread.cpp" line="463"/>
         <source>Error writing file to disk</source>
         <translation>将文件写入磁盘时出错</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="463"/>
+        <location filename="../downloadthread.cpp" line="482"/>
         <source>Error downloading: %1</source>
         <translation>下载文件错误，已下载：%1</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="686"/>
+        <location filename="../downloadthread.cpp" line="705"/>
+        <location filename="../downloadthread.cpp" line="757"/>
         <source>Error writing to storage (while flushing)</source>
         <translation>刷写存储时出错</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="693"/>
+        <location filename="../downloadthread.cpp" line="712"/>
+        <location filename="../downloadthread.cpp" line="764"/>
         <source>Error writing to storage (while fsync)</source>
         <translation>在fsync时写入存储时出错</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="674"/>
+        <location filename="../downloadthread.cpp" line="693"/>
         <source>Download corrupt. Hash does not match</source>
         <translation>下载的文件损坏。 哈希值不匹配</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="114"/>
+        <location filename="../downloadthread.cpp" line="118"/>
+        <source>unmounting drive</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../downloadthread.cpp" line="138"/>
         <source>opening drive</source>
         <translation>打开驱动器</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="300"/>
+        <location filename="../downloadthread.cpp" line="319"/>
         <source>Write error while trying to zero out last part of card.&lt;br&gt;Card could be advertising wrong capacity (possible counterfeit).</source>
         <translation>写入镜像失败&lt;br&gt;SD卡可能损坏。</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="389"/>
+        <location filename="../downloadthread.cpp" line="408"/>
         <source>starting download</source>
         <translation>开始下载</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="719"/>
+        <location filename="../downloadthread.cpp" line="747"/>
         <source>Error writing first block (partition table)</source>
         <translation>写入第一个块（分区表）时出错</translation>
     </message>
     <message>
-        <location filename="../downloadthread.cpp" line="798"/>
+        <location filename="../downloadthread.cpp" line="832"/>
         <source>Verifying write failed. Contents of SD card is different from what was written to it.</source>
         <translation>验证写入失败。 SD卡的内容与写入的内容不同。</translation>
     </message>
@@ -256,27 +242,27 @@
 <context>
     <name>ImageWriter</name>
     <message>
-        <location filename="../imagewriter.cpp" line="257"/>
+        <location filename="../imagewriter.cpp" line="248"/>
         <source>Storage capacity is not large enough.&lt;br&gt;Needs to be at least %1 GB.</source>
         <translation>存储容量不足。&lt;br&gt;至少需要%1 GB的空白空间.</translation>
     </message>
     <message>
-        <location filename="../imagewriter.cpp" line="263"/>
+        <location filename="../imagewriter.cpp" line="254"/>
         <source>Input file is not a valid disk image.&lt;br&gt;File size %1 bytes is not a multiple of 512 bytes.</source>
         <translation>输入文件不是有效的磁盘映像。&lt;br&gt;文件大小%1字节不是512字节的倍数。</translation>
     </message>
     <message>
-        <location filename="../imagewriter.cpp" line="445"/>
+        <location filename="../imagewriter.cpp" line="442"/>
         <source>Downloading and writing image</source>
         <translation>下载和写入镜像</translation>
     </message>
     <message>
-        <location filename="../imagewriter.cpp" line="578"/>
+        <location filename="../imagewriter.cpp" line="575"/>
         <source>Select image</source>
         <translation>选择镜像</translation>
     </message>
     <message>
-        <location filename="../imagewriter.cpp" line="979"/>
+        <location filename="../imagewriter.cpp" line="864"/>
         <source>Would you like to prefill the wifi password from the system keychain?</source>
         <translation type="unfinished"></translation>
     </message>
@@ -320,22 +306,22 @@
 <context>
     <name>OptionsPopup</name>
     <message>
-        <location filename="../OptionsPopup.qml" line="79"/>
+        <location filename="../OptionsPopup.qml" line="80"/>
         <source>Advanced options</source>
         <translation>高级设置</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="96"/>
+        <location filename="../OptionsPopup.qml" line="97"/>
         <source>Image customization options</source>
         <translation>镜像自定义选项</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="104"/>
+        <location filename="../OptionsPopup.qml" line="105"/>
         <source>for this session only</source>
         <translation>仅限本次</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="105"/>
+        <location filename="../OptionsPopup.qml" line="106"/>
         <source>to always use</source>
         <translation>永久保存</translation>
     </message>
@@ -344,22 +330,22 @@
         <translation type="vanished">禁用扫描</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="119"/>
+        <location filename="../OptionsPopup.qml" line="120"/>
         <source>Set hostname:</source>
         <translation>设置主机名：</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="138"/>
+        <location filename="../OptionsPopup.qml" line="140"/>
         <source>Enable SSH</source>
         <translation>开启SSH服务</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="160"/>
+        <location filename="../OptionsPopup.qml" line="162"/>
         <source>Use password authentication</source>
         <translation>使用密码登录</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="170"/>
+        <location filename="../OptionsPopup.qml" line="172"/>
         <source>Allow public-key authentication only</source>
         <translation>只允许使用公匙登录</translation>
     </message>
@@ -368,63 +354,63 @@
         <translation type="vanished">设置&apos;%1&apos;用户的密码：</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="188"/>
+        <location filename="../OptionsPopup.qml" line="190"/>
         <source>Set authorized_keys for &apos;%1&apos;:</source>
         <translation>设置%1用户的登录密匙：</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="261"/>
+        <location filename="../OptionsPopup.qml" line="264"/>
         <source>Configure wireless LAN</source>
         <translation>配置WiFi</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="280"/>
+        <location filename="../OptionsPopup.qml" line="283"/>
         <source>SSID:</source>
         <translation>热点名：</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="234"/>
-        <location filename="../OptionsPopup.qml" line="300"/>
+        <location filename="../OptionsPopup.qml" line="237"/>
+        <location filename="../OptionsPopup.qml" line="303"/>
         <source>Password:</source>
         <translation>密码：</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="200"/>
+        <location filename="../OptionsPopup.qml" line="203"/>
         <source>Set username and password</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="219"/>
+        <location filename="../OptionsPopup.qml" line="222"/>
         <source>Username:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="295"/>
+        <location filename="../OptionsPopup.qml" line="298"/>
         <source>Hidden SSID</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="316"/>
+        <location filename="../OptionsPopup.qml" line="319"/>
         <source>Show password</source>
         <translation>显示密码</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="321"/>
+        <location filename="../OptionsPopup.qml" line="324"/>
         <source>Wireless LAN country:</source>
         <translation>WIFI国家：</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="332"/>
+        <location filename="../OptionsPopup.qml" line="335"/>
         <source>Set locale settings</source>
         <translation>语言设置</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="342"/>
+        <location filename="../OptionsPopup.qml" line="345"/>
         <source>Time zone:</source>
         <translation>时区：</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="352"/>
+        <location filename="../OptionsPopup.qml" line="355"/>
         <source>Keyboard layout:</source>
         <translation>键盘布局：</translation>
     </message>
@@ -433,27 +419,27 @@
         <translation type="vanished">跳过首次启动向导</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="365"/>
+        <location filename="../OptionsPopup.qml" line="368"/>
         <source>Persistent settings</source>
         <translation>永久设置</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="373"/>
+        <location filename="../OptionsPopup.qml" line="376"/>
         <source>Play sound when finished</source>
         <translation>完成后播放提示音</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="377"/>
+        <location filename="../OptionsPopup.qml" line="380"/>
         <source>Eject media when finished</source>
         <translation>完成后弹出磁盘</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="381"/>
+        <location filename="../OptionsPopup.qml" line="384"/>
         <source>Enable telemetry</source>
         <translation>启用遥测</translation>
     </message>
     <message>
-        <location filename="../OptionsPopup.qml" line="394"/>
+        <location filename="../OptionsPopup.qml" line="397"/>
         <source>SAVE</source>
         <translation>保存</translation>
     </message>
@@ -469,27 +455,32 @@
 <context>
     <name>UseSavedSettingsPopup</name>
     <message>
-        <location filename="../UseSavedSettingsPopup.qml" line="72"/>
+        <location filename="../UseSavedSettingsPopup.qml" line="73"/>
         <source>Warning: advanced settings set</source>
         <translation>警告：高级设置已设置</translation>
     </message>
     <message>
-        <location filename="../UseSavedSettingsPopup.qml" line="86"/>
+        <location filename="../UseSavedSettingsPopup.qml" line="87"/>
         <source>Would you like to apply the image customization settings saved earlier?</source>
         <translation>您要应用之前保存的自定义镜像设置吗？</translation>
     </message>
     <message>
-        <location filename="../UseSavedSettingsPopup.qml" line="95"/>
+        <location filename="../UseSavedSettingsPopup.qml" line="96"/>
+        <source>NO</source>
+        <translation type="unfinished">不</translation>
+    </message>
+    <message>
+        <location filename="../UseSavedSettingsPopup.qml" line="106"/>
         <source>NO, CLEAR SETTINGS</source>
         <translation>清空所有设置</translation>
     </message>
     <message>
-        <location filename="../UseSavedSettingsPopup.qml" line="105"/>
+        <location filename="../UseSavedSettingsPopup.qml" line="116"/>
         <source>YES</source>
         <translation>是</translation>
     </message>
     <message>
-        <location filename="../UseSavedSettingsPopup.qml" line="115"/>
+        <location filename="../UseSavedSettingsPopup.qml" line="126"/>
         <source>EDIT SETTINGS</source>
         <translation>编辑设置</translation>
     </message>
@@ -530,7 +521,7 @@
     </message>
     <message>
         <location filename="../main.qml" line="147"/>
-        <location filename="../main.qml" line="1038"/>
+        <location filename="../main.qml" line="1041"/>
         <source>CHOOSE STORAGE</source>
         <translation>选择SD卡</translation>
     </message>
@@ -545,7 +536,7 @@
         <translation>烧录</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="968"/>
+        <location filename="../main.qml" line="971"/>
         <source>Writing... %1%</source>
         <translation>写入中...%1%</translation>
     </message>
@@ -570,7 +561,7 @@
     </message>
     <message>
         <location filename="../main.qml" line="221"/>
-        <location filename="../main.qml" line="965"/>
+        <location filename="../main.qml" line="968"/>
         <source>Cancelling...</source>
         <translation>取消...</translation>
     </message>
@@ -581,8 +572,8 @@
     </message>
     <message>
         <location filename="../main.qml" line="232"/>
-        <location filename="../main.qml" line="988"/>
-        <location filename="../main.qml" line="1057"/>
+        <location filename="../main.qml" line="991"/>
+        <location filename="../main.qml" line="1060"/>
         <source>Finalizing...</source>
         <translation>正在完成...</translation>
     </message>
@@ -613,7 +604,7 @@
     </message>
     <message>
         <location filename="../main.qml" line="505"/>
-        <location filename="../main.qml" line="1022"/>
+        <location filename="../main.qml" line="1025"/>
         <source>Erase</source>
         <translation>擦除</translation>
     </message>
@@ -668,12 +659,12 @@
         <translation>有较新版本的rpi-imager。&lt;br&gt;需要下载更新吗？</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="998"/>
+        <location filename="../main.qml" line="1001"/>
         <source>Preparing to write... (%1)</source>
         <translation>写入中 (%1)</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="1023"/>
+        <location filename="../main.qml" line="1026"/>
         <source>&lt;b&gt;%1&lt;/b&gt; has been erased&lt;br&gt;&lt;br&gt;You can now remove the SD card from the reader</source>
         <translation>&lt;b&gt;%1 &lt;/ b&gt;已被删除&lt;br&gt; &lt;br&gt;您现在可以从读取器中取出SD卡</translation>
     </message>
@@ -682,17 +673,17 @@
         <translation type="vanished">&lt;b&gt;%1&lt;/b&gt; 已经成功烧录到 &lt;b&gt;%2&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="1098"/>
+        <location filename="../main.qml" line="1101"/>
         <source>Error parsing os_list.json</source>
         <translation>解析 os_list.json 错误</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="1271"/>
+        <location filename="../main.qml" line="1274"/>
         <source>Connect an USB stick containing images first.&lt;br&gt;The images must be located in the root folder of the USB stick.</source>
         <translation>连接包含镜像的U盘。&lt;br&gt;镜像必须位于U盘的根文件夹中。</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="1287"/>
+        <location filename="../main.qml" line="1290"/>
         <source>SD card is write protected.&lt;br&gt;Push the lock switch on the left side of the card upwards, and try again.</source>
         <translation>SD卡具有写保护。&lt;br&gt;尝试向上推SD卡的左侧的锁定开关，然后重试。</translation>
     </message>
@@ -737,27 +728,27 @@
         <translation type="vanished">继续</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="947"/>
+        <location filename="../main.qml" line="950"/>
         <source>Error downloading OS list from Internet</source>
         <translation>下载镜像列表错误</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="991"/>
+        <location filename="../main.qml" line="994"/>
         <source>Verifying... %1%</source>
         <translation>验证文件中...%1%</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="1014"/>
+        <location filename="../main.qml" line="1017"/>
         <source>Error</source>
         <translation>错误</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="1021"/>
+        <location filename="../main.qml" line="1024"/>
         <source>Write Successful</source>
         <translation>烧录成功</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="1030"/>
+        <location filename="../main.qml" line="1033"/>
         <source>&lt;b&gt;%1&lt;/b&gt; has been written to &lt;b&gt;%2&lt;/b&gt;&lt;br&gt;&lt;br&gt;You can now remove the SD card from the reader</source>
         <translation>&lt;b&gt;%1&lt;/b&gt; 已经成功烧录到 &lt;b&gt;%2&lt;/b&gt;&lt;br&gt;&lt;br&gt;上了，你可以卸载SD卡了</translation>
     </message>
