@@ -3,14 +3,15 @@
  * Copyright (C) 2020 Raspberry Pi Ltd
  */
 
+#include "downloadextractthread.h"
 #include "imagewriter.h"
 #include "drivelistitem.h"
-#include "downloadextractthread.h"
 #include "dependencies/drivelist/src/drivelist.hpp"
 #include "dependencies/sha256crypt/sha256crypt.h"
 #include "driveformatthread.h"
 #include "localfileextractthread.h"
 #include "downloadstatstelemetry.h"
+#include "wlancredentials.h"
 #include <archive.h>
 #include <archive_entry.h>
 #include <random>
@@ -38,17 +39,10 @@
 #endif
 #ifdef Q_OS_DARWIN
 #include <QMessageBox>
-#include <security/security.h>
 #endif
 
 #ifdef Q_OS_WIN
 #include <windows.h>
-#include <winioctl.h>
-#include <wlanapi.h>
-#ifndef WLAN_PROFILE_GET_PLAINTEXT_KEY
-#define WLAN_PROFILE_GET_PLAINTEXT_KEY 4
-#endif
-
 #include <QWinTaskbarButton>
 #include <QWinTaskbarProgress>
 #endif
@@ -57,16 +51,10 @@
 #include <QtPlatformHeaders/QEglFSFunctions>
 #endif
 
-#ifdef Q_OS_LINUX
-#ifndef QT_NO_DBUS
-#include "linux/networkmanagerapi.h"
-#endif
-#endif
-
 ImageWriter::ImageWriter(QObject *parent)
     : QObject(parent), _repo(QUrl(QString(OSLIST_URL))), _dlnow(0), _verifynow(0),
       _engine(nullptr), _thread(nullptr), _verifyEnabled(false), _cachingEnabled(false),
-      _embeddedMode(false), _online(false), _trans(nullptr)
+      _embeddedMode(false), _online(false), _customCacheFile(false), _trans(nullptr)
 {
     connect(&_polltimer, SIGNAL(timeout()), SLOT(pollProgress()));
 
@@ -349,8 +337,11 @@ void ImageWriter::startWrite()
 
 void ImageWriter::onCacheFileUpdated(QByteArray sha256)
 {
-    _settings.setValue("caching/lastDownloadSHA256", sha256);
-    _settings.sync();
+    if (!_customCacheFile)
+    {
+        _settings.setValue("caching/lastDownloadSHA256", sha256);
+        _settings.sync();
+    }
     _cachedFileHash = sha256;
     qDebug() << "Done writing cache file";
 }
@@ -421,6 +412,14 @@ void ImageWriter::setCustomOsListUrl(const QUrl &url)
     _repo = url;
 }
 
+void ImageWriter::setCustomCacheFile(const QString &cacheFile, const QByteArray &sha256)
+{
+    _cacheFileName = cacheFile;
+    _cachedFileHash = QFile::exists(cacheFile) ? sha256 : "";
+    _customCacheFile = true;
+    _cachingEnabled = true;
+}
+
 /* Start polling the list of available drives */
 void ImageWriter::startDriveListPolling()
 {
@@ -852,154 +851,23 @@ QStringList ImageWriter::getKeymapLayoutList()
 
 QString ImageWriter::getSSID()
 {
-    /* Qt used to have proper bearer management that was able to provide a list of
-       SSIDs, but since they retired it, resort to calling platform specific tools for now.
-       Minimal implementation that only gets the currently connected SSID */
-
-    QString program, regexpstr, ssid;
-    QStringList args;
-    QProcess proc;
-
-#ifdef Q_OS_WIN
-    program = "netsh";
-    args << "wlan" << "show" << "interfaces";
-    regexpstr = "[ \t]+SSID[ \t]*: (.+)";
-#else
-#ifdef Q_OS_DARWIN
-    program = "/System/Library/PrivateFrameworks/Apple80211.framework/Versions/Current/Resources/airport";
-    args << "-I";
-    regexpstr = "[ \t]+SSID: (.+)";
-#else
-    program = "iwgetid";
-    args << "-r";
-#endif
-#endif
-
-    proc.start(program, args);
-    if (proc.waitForStarted(2000) && proc.waitForFinished(2000))
-    {
-        if (regexpstr.isEmpty())
-        {
-            ssid = proc.readAll().trimmed();
-        }
-        else
-        {
-            QRegularExpression rx(regexpstr);
-            const QList<QByteArray> outputlines = proc.readAll().replace('\r', "").split('\n');
-
-            for (const QByteArray &line : outputlines) {
-                QRegularExpressionMatch match = rx.match(line);
-                if (match.hasMatch())
-                {
-                    ssid = match.captured(1);
-                    break;
-                }
-            }
-        }
-    }
-
-    return ssid;
+    return WlanCredentials::instance()->getSSID();
 }
 
-QString ImageWriter::getPSK(const QString &ssid)
+QString ImageWriter::getPSK()
 {
-#ifdef Q_OS_WIN
-    /* Windows allows retrieving wifi PSK */
-    HANDLE h;
-    DWORD ret = 0;
-    DWORD supportedVersion = 0;
-    DWORD clientVersion = 2;
-    QString psk;
-
-    if (WlanOpenHandle(clientVersion, NULL, &supportedVersion, &h) != ERROR_SUCCESS)
-        return QString();
-
-    PWLAN_INTERFACE_INFO_LIST ifList = NULL;
-
-    if (WlanEnumInterfaces(h, NULL, &ifList) == ERROR_SUCCESS)
-    {
-        for (int i=0; i < ifList->dwNumberOfItems; i++)
-        {
-            PWLAN_PROFILE_INFO_LIST profileList = NULL;
-
-            if (WlanGetProfileList(h, &ifList->InterfaceInfo[i].InterfaceGuid,
-                                   NULL, &profileList) == ERROR_SUCCESS)
-            {
-                for (int j=0; j < profileList->dwNumberOfItems; j++)
-                {
-                    QString s = QString::fromWCharArray(profileList->ProfileInfo[j].strProfileName);
-                    qDebug() << "Enumerating wifi profiles, SSID found:" << s << " looking for:" << ssid;
-
-                    if (s == ssid) {
-                        DWORD flags = WLAN_PROFILE_GET_PLAINTEXT_KEY;
-                        DWORD access = 0;
-                        DWORD ret = 0;
-                        LPWSTR xmlstr = NULL;
-
-                        if ( (ret = WlanGetProfile(h, &ifList->InterfaceInfo[i].InterfaceGuid, profileList->ProfileInfo[j].strProfileName,
-                                          NULL, &xmlstr, &flags, &access)) == ERROR_SUCCESS && xmlstr)
-                        {
-                            QString xml = QString::fromWCharArray(xmlstr);
-                            qDebug() << "XML wifi profile:" << xml;
-                            QRegularExpression rx("<keyMaterial>(.+)</keyMaterial>");
-                            QRegularExpressionMatch match = rx.match(xml);
-
-                            if (match.hasMatch()) {
-                                psk = match.captured(1);
-                            }
-
-                            WlanFreeMemory(xmlstr);
-                            break;
-                        }
-                    }
-                }
-            }
-
-            if (profileList) {
-                WlanFreeMemory(profileList);
-            }
-        }
-    }
-
-    if (ifList)
-        WlanFreeMemory(ifList);
-    WlanCloseHandle(h, NULL);
-
-    return psk;
-
-#else
 #ifdef Q_OS_DARWIN
-    SecKeychainRef keychainRef;
-    QString psk;
-    QByteArray ssidAscii = ssid.toLatin1();
-
+    /* On OSX the user is presented with a prompt for the admin password when opening the system key chain.
+     * Ask if user wants to obtain the wlan password first to make sure this is desired and
+     * to provide the user with context. */
     if (QMessageBox::question(nullptr, "",
-                          tr("Would you like to prefill the wifi password from the system keychain?")) == QMessageBox::Yes)
+                          tr("Would you like to prefill the wifi password from the system keychain?")) != QMessageBox::Yes)
     {
-        if (SecKeychainOpen("/Library/Keychains/System.keychain", &keychainRef) == errSecSuccess)
-        {
-            UInt32 resultLen;
-            void *result;
-            if (SecKeychainFindGenericPassword(keychainRef, 0, NULL, ssidAscii.length(), ssidAscii.constData(), &resultLen, &result, NULL) == errSecSuccess)
-            {
-                psk = QByteArray((char *) result, resultLen);
-                SecKeychainItemFreeContent(NULL, result);
-            }
-            CFRelease(keychainRef);
-        }
+        return QString();
     }
+#endif
 
-    return psk;
-#else
-#ifndef QT_NO_DBUS
-    NetworkManagerApi nm;
-    return nm.getPSK();
-#else
-    Q_UNUSED(ssid)
-    return QString();
-#endif
-#endif
-#endif
+    return WlanCredentials::instance()->getPSK();
 }
 
 bool ImageWriter::getBoolSetting(const QString &key)
@@ -1232,6 +1100,26 @@ QString ImageWriter::detectPiKeyboard()
     return QString();
 }
 
+QString ImageWriter::getCurrentUser()
+{
+    QString user = qgetenv("USER");
+
+    if (user.isEmpty())
+        user = qgetenv("USERNAME");
+
+    user = user.toLower();
+    if (user.contains(" "))
+    {
+        auto names = user.split(" ");
+        user = names.first();
+    }
+
+    if (user.isEmpty() || user == "root")
+        user = "pi";
+
+    return user;
+}
+
 bool ImageWriter::hasMouse()
 {
     return !_embeddedMode || QFile::exists("/dev/input/mouse0");
